@@ -8,7 +8,6 @@ import setproctitle
 import shlex
 import click
 import configparser
-import wget
 import hashlib
 import codecs
 import subprocess
@@ -19,6 +18,8 @@ import requests
 import json
 import asyncio
 import websockets
+import urllib3
+import shutil
 from multiprocessing import Lock
 from time import strftime, localtime
 from urllib.error import URLError
@@ -357,6 +358,12 @@ class SQLCli(object):
         if self.MultiProcessManager is not None:
             self.MultiProcessManager.shutdown()
 
+        # 关闭LogFile
+        if self.logfile is not None:
+            self.logfile.flush()
+            self.logfile.close()
+            self.logfile = None
+
     # 加载CLI的各种特殊命令集
     def register_special_commands(self):
 
@@ -1023,17 +1030,41 @@ class SQLCli(object):
     def sleep(cls, arg, **_):
         if not arg:
             message = "Missing required argument, sleep [seconds]."
-            return [(None, None, None, None, message)]
+            return [{
+                "title": None,
+                "rows": None,
+                "headers": None,
+                "columntypes": None,
+                "status": message
+            }]
         try:
             m_Sleep_Time = int(arg)
             if m_Sleep_Time <= 0:
                 message = "Parameter must be a valid number, sleep [seconds]."
-                return [(None, None, None, None, message)]
+                return [{
+                    "title": None,
+                    "rows": None,
+                    "headers": None,
+                    "columntypes": None,
+                    "status": message
+                }]
             time.sleep(m_Sleep_Time)
         except ValueError:
             message = "Parameter must be a number, sleep [seconds]."
-            return [(None, None, None, None, message)]
-        return [(None, None, None, None, None)]
+            return [{
+                "title": None,
+                "rows": None,
+                "headers": None,
+                "columntypes": None,
+                "status": message
+            }]
+        return [{
+            "title": None,
+            "rows": None,
+            "headers": None,
+            "columntypes": None,
+            "status": None
+        }]
 
     # 从文件中执行SQL
     @staticmethod
@@ -1444,7 +1475,8 @@ class SQLCli(object):
                         if p_result["script"] is None:
                             # 控制台应用，不再打印SQL语句到控制台（因为用户已经输入了)
                             m_EchoFlag = m_EchoFlag & ~OFLAG_CONSOLE
-                        self.echo(p_result["formattedsql"], m_EchoFlag)
+                        if p_result["formattedsql"] is not None:
+                            self.echo(p_result["formattedsql"], m_EchoFlag)
                         # 打印改写后的SQL
                         if len(p_result["rewrotedsql"]) != 0:
                             m_EchoFlag = OFLAG_LOGFILE | OFLAG_LOGGER | OFLAG_CONSOLE | OFLAG_SPOOL
@@ -1532,6 +1564,9 @@ class SQLCli(object):
             # 当调用了exit或者quit的时候，会收到EOFError，这里直接抛出
             raise e
         except SQLCliException as e:
+            if "SQLCLI_DEBUG" in os.environ:
+                print('traceback.print_exc():\n%s' % traceback.print_exc())
+                print('traceback.format_exc():\n%s' % traceback.format_exc())
             # 用户执行的SQL出了错误, 由于SQLExecute已经打印了错误消息，这里直接退出
             self.output(None, e.message)
             if self.SQLOptions.get("WHENEVER_SQLERROR").upper() == "EXIT":
@@ -1580,8 +1615,10 @@ class SQLCli(object):
                         print("Driver [" + m_driversection + "], need upgrade ...")
                         # 重新下载新的文件到本地
                         try:
-                            wget.download(m_driver_downloadurl, out=m_LocalJarFile)
-                            print("")
+                            http = urllib3.PoolManager()
+                            with http.request('GET', m_driver_downloadurl, preload_content=False) as r, \
+                                    open(m_LocalJarFile, 'wb') as out_file:
+                                shutil.copyfileobj(r, out_file)
                         except URLError:
                             print('traceback.print_exc():\n%s' % traceback.print_exc())
                             print('traceback.format_exc():\n%s' % traceback.format_exc())
@@ -1651,6 +1688,12 @@ class SQLCli(object):
         # 退出进程
         self.echo("Disconnected.")
 
+        # 关闭LogFile
+        if self.logfile is not None:
+            self.logfile.flush()
+            self.logfile.close()
+            self.logfile = None
+
         # 还原进程标题
         setproctitle.setproctitle(m_Cli_ProcessTitleBak)
 
@@ -1666,17 +1709,20 @@ class SQLCli(object):
         if self.SQLOptions.get("SILENT").upper() != 'ON':
             if Flags & OFLAG_LOGFILE:
                 if self.SQLOptions.get("ECHO").upper() == 'ON' and self.logfile is not None:
-                    click.echo(s, file=self.logfile)
+                    print(s, file=self.logfile)
+                    self.logfile.flush()
             if Flags & OFLAG_SPOOL:
                 if self.SQLOptions.get("ECHO").upper() == 'ON' and self.SpoolFileHandler is not None:
                     for m_SpoolFileHandler in self.SpoolFileHandler:
-                        click.echo(s, file=m_SpoolFileHandler)
+                        print(s, file=m_SpoolFileHandler)
+                        m_SpoolFileHandler.flush()
             if Flags & OFLAG_LOGGER:
                 if self.logger is not None:
                     self.logger.info(s)
             if Flags & OFLAG_ECHO:
                 if self.EchoFileHandler is not None:
-                    click.echo(s, file=self.EchoFileHandler)
+                    print(s, file=self.EchoFileHandler)
+                    self.EchoFileHandler.flush()
             if Flags & OFLAG_CONSOLE:
                 try:
                     click.secho(s, **kwargs, file=self.Console)
